# Index of Names

## A

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- add_content - `gtoolz.add_content`
- add_or_replace - `gtoolz.add_or_replace`
- add_selection - `gtoolz.MenuBox.add_selection`
- askYN - `gtoolz.askYN`
- askYN_demo - `gtoolz.askYN_demo`

## B

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- bclr - `gtoolz.MenuBox.bclr`
- bg_colors_d - `gtoolz.bg_colors_d`
- BLACK - `gtoolz.BLACK`
- bool_val - `gtoolz.bool_val`
- bool_val_demo - `gtoolz.bool_val_demo`
- boxed - `gtoolz.boxed`
- boxed_demo - `gtoolz.boxed_demo`
- browseit - `gtoolz.browseit`
- busy - `gtoolz.Spinner.busy`

## C

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- cat_file - `gtoolz.cat_file`
- center - `gtoolz.MenuBox.center`
- centered
  - `gtoolz.centered`
  - `gtoolz.Spinner.centered`
- centered_demo - `gtoolz.centered_demo`
- cfg_val - `gtoolz.cfg_val`
- chk_substr - `gtoolz.chk_substr`
- chkbox_demo - `gtoolz.chkbox_demo`
- chklst - `gtoolz.chklst`
- chr_cnt - `gtoolz.Spinner.chr_cnt`
- chunkit - `gtoolz.chunkit`
- cinput - `gtoolz.cinput`
- clines - `gtoolz.MenuBox.clines`
- clr_cnt - `gtoolz.Spinner.clr_cnt`
- clr_coded - `gtoolz.clr_coded`
- clr_coded_demo - `gtoolz.clr_coded_demo`
- clr_demo - `gtoolz.clr_demo`
- clr_tst - `gtoolz.clr_tst`
- cls - `gtoolz.cls`
- cnt - `gtoolz.MenuBox.cnt`
- cnvrt2lol - `gtoolz.cnvrt2lol`
- cnvrt2lol_demo - `gtoolz.cnvrt2lol_demo`
- COLOR - `gtoolz.Spinner.COLOR`
- color - `gtoolz.Spinner.color`
- colors - `gtoolz.Spinner.colors`
- columned - `gtoolz.columned`
- columned_demo - `gtoolz.columned_demo`
- comma_join - `gtoolz.comma_join`
- comma_join_demo - `gtoolz.comma_join_demo`
- comma_split - `gtoolz.comma_split`
- comma_split_demo - `gtoolz.comma_split_demo`
- cond_num - `gtoolz.cond_num`
- convert_temp - `gtoolz.convert_temp`

## D

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- dbug - `gtoolz.dbug`
- dbug_demo - `gtoolz.dbug_demo`
- ddbug - `gtoolz.ddbug`
- delay - `gtoolz.Spinner.delay`
- display_in_cols - `gtoolz.display_in_cols`
- do_close - `gtoolz.do_close`
- do_edit - `gtoolz.do_edit`
- do_func_demos - `gtoolz.do_func_demos`
- do_func_docs - `gtoolz.do_func_docs`
- do_logo - `gtoolz.do_logo`
- do_logo_demo - `gtoolz.do_logo_demo`
- do_prcnt_bar - `gtoolz.do_prcnt_bar`
- docvars - `gtoolz.docvars`
- dtime - `gtoolz.dtime`
- dtree - `gtoolz.dtree`
- dtree_demo - `gtoolz.dtree_demo`

## E

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- elapsed - `gtoolz.Spinner.elapsed`
- escape_ansi - `gtoolz.escape_ansi`
- etime - `gtoolz.Spinner.etime`

## F

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- fg_colors_d - `gtoolz.fg_colors_d`
- file_exists - `gtoolz.file_exists`
- find_file_in_dirs - `gtoolz.find_file_in_dirs`
- first_matched_line - `gtoolz.first_matched_line`
- fixlol - `gtoolz.fixlol`
- flattenit - `gtoolz.flattenit`
- flush - `gtoolz.Transcript.flush`
- from_to - `gtoolz.from_to`
- funcname - `gtoolz.funcname`

## G

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- gblock - `gtoolz.gblock`
- gblock_demo - `gtoolz.gblock_demo`
- gclr - `gtoolz.gclr`
- gclr_demo - `gtoolz.gclr_demo`
- gcolumnize - `gtoolz.gcolumnize`
- gcolumnize_demo - `gtoolz.gcolumnize_demo`
- gcontains - `gtoolz.gcontains`
- get_boxchrs - `gtoolz.get_boxchrs`
- get_columns - `gtoolz.get_columns`
- get_dtime_format - `gtoolz.get_dtime_format`
- get_elems - `gtoolz.get_elems`
- get_elems_demo - `gtoolz.get_elems_demo`
- get_html_tables - `gtoolz.get_html_tables`
- get_html_tst - `gtoolz.get_html_tst`
- get_mod_docs - `gtoolz.get_mod_docs`
- get_random_line - `gtoolz.get_random_line`
- gline - `gtoolz.gline`
- gline_demo - `gtoolz.gline_demo`
- grep_lines - `gtoolz.grep_lines`
- gselect - `gtoolz.gselect`
- gselect_demo - `gtoolz.gselect_demo`
- gtable - `gtoolz.gtable`
- gtable_demo - `gtoolz.gtable_demo`
- gtitle - `gtoolz.gtitle`
- gtoolz - `gtoolz`

## H

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- handleCFG - `gtoolz.handleCFG`
- handleOPTS - `gtoolz.handleOPTS`
- has_alnum - `gtoolz.has_alnum`
- has_substr - `gtoolz.has_substr`

## I

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- ireplace - `gtoolz.ireplace`
- isempty - `gtoolz.isempty`
- islod - `gtoolz.islod`
- islol - `gtoolz.islol`
- islols_demo - `gtoolz.islols_demo`
- islos - `gtoolz.islos`
- isnumber - `gtoolz.isnumber`
- isnumber_demo - `gtoolz.isnumber_demo`

## J

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- join - `gtoolz.ThreadWithReturn.join`

## K

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- key_swap - `gtoolz.key_swap`
- kv_cols - `gtoolz.kv_cols`
- kv_cols_demo - `gtoolz.kv_cols_demo`
- kvarg_val - `gtoolz.kvarg_val`
- kvarg_val_demo - `gtoolz.kvarg_val_demo`

## L

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- lineno - `gtoolz.lineno`
- list_files - `gtoolz.list_files`
- logfile - `gtoolz.Transcript.logfile`
- long_proc - `gtoolz.long_proc`

## M

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- main - `gtoolz.main`
- matrix - `gtoolz.matrix`
- max_width_lol - `gtoolz.max_width_lol`
- maxof - `gtoolz.maxof`
- maxof_demo - `gtoolz.maxof_demo`
- MenuBox - `gtoolz.MenuBox`
- msgs - `gtoolz.MenuBox.msgs`

## N

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- name - `gtoolz.MenuBox.name`
- nclen - `gtoolz.nclen`

## P

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- pp_d - `gtoolz.pp_d`
- printit - `gtoolz.printit`
- printit_demo - `gtoolz.printit_demo`
- prog - `gtoolz.Spinner.prog`
- progress - `gtoolz.progress`
- purify - `gtoolz.purify`
- pyscraper - `gtoolz.pyscraper`

## Q

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- quick_plot - `gtoolz.quick_plot`
- quick_plot_demo - `gtoolz.quick_plot_demo`

## R

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- reduce_line - `gtoolz.reduce_line`
- regex_col - `gtoolz.regex_col`
- remap_keys - `gtoolz.remap_keys`
- replace_all - `gtoolz.replace_all`
- RESET
  - `gtoolz.RESET`
  - `gtoolz.Spinner.RESET`
- retry - `gtoolz.retry`
- rgb - `gtoolz.rgb`
- rootname - `gtoolz.rootname`
- rowscols_cols - `gtoolz.rowscols_cols`
- ruleit - `gtoolz.ruleit`
- ruleit_demo - `gtoolz.ruleit_demo`
- run - `gtoolz.ThreadWithReturn.run`
- run_cmd - `gtoolz.run_cmd`
- run_cmd_demo - `gtoolz.run_cmd_demo`
- run_cmd_threaded - `gtoolz.run_cmd_threaded`

## S

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- sayit - `gtoolz.sayit`
- sayit_demo - `gtoolz.sayit_demo`
- SCRIPT - `gtoolz.SCRIPT`
- select_file - `gtoolz.select_file`
- selections - `gtoolz.MenuBox.selections`
- shades - `gtoolz.shades`
- shadowed - `gtoolz.shadowed`
- show - `gtoolz.MenuBox.show`
- sorted_add - `gtoolz.sorted_add`
- spin_backover - `gtoolz.Spinner.spin_backover`
- spin_proc - `gtoolz.Spinner.spin_proc`
- Spinner - `gtoolz.Spinner`
- spinner - `gtoolz.Spinner.spinner`
- Spinner_demo - `gtoolz.Spinner_demo`
- spinner_visible - `gtoolz.Spinner.spinner_visible`
- split_codes - `gtoolz.split_codes`
- split_codes_demo - `gtoolz.split_codes_demo`
- splitit - `gtoolz.splitit`
- start_time - `gtoolz.Spinner.start_time`
- style - `gtoolz.Spinner.style`
- style_len - `gtoolz.Spinner.style_len`
- styles_d - `gtoolz.styles_d`
- sub_color - `gtoolz.sub_color`

## T

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- terminal - `gtoolz.Transcript.terminal`
- thread - `gtoolz.Spinner.thread`
- ThreadWithReturn - `gtoolz.ThreadWithReturn`
- TIME_COLOR - `gtoolz.Spinner.TIME_COLOR`
- time_color - `gtoolz.Spinner.time_color`
- title - `gtoolz.MenuBox.title`
- Transcript - `gtoolz.Transcript`
- transcript_demo - `gtoolz.transcript_demo`
- transcript_start - `gtoolz.transcript_start`
- transcript_stop - `gtoolz.transcript_stop`
- try_it - `gtoolz.try_it`
- try_to_get - `gtoolz.try_to_get`
- tst - `gtoolz.tst`
- TXT_COLOR - `gtoolz.Spinner.TXT_COLOR`

## U

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- usr_input - `gtoolz.usr_input`
- usr_input_demo - `gtoolz.usr_input_demo`
- usr_update - `gtoolz.usr_update`
- usr_update_demo - `gtoolz.usr_update_demo`

## W

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- wrapit - `gtoolz.wrapit`
- wrapit_demo - `gtoolz.wrapit_demo`
- write - `gtoolz.Transcript.write`
- write_file - `gtoolz.write_file`
- write_next - `gtoolz.Spinner.write_next`

## X

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- xlate_clr - `gtoolz.xlate_clr`

## _

A - B - C - D - E - F - G - H - I - J - K - L - M - N - P - Q - R - S - T - U - W - X - _

- __enter__ - `gtoolz.Spinner.__enter__`
- __exit__ - `gtoolz.Spinner.__exit__`
- __init__
  - `gtoolz.MenuBox.__init__`
  - `gtoolz.Spinner.__init__`
  - `gtoolz.ThreadWithReturn.__init__`
  - `gtoolz.Transcript.__init__`
- __version__ - `gtoolz.__version__`
- _return - `gtoolz.ThreadWithReturn._return`
- _screen_lock - `gtoolz.Spinner._screen_lock`